@@ -60,7 +60,7 @@ use PPI             ();
 use PPI::Exception  ();
 use PPI::Singletons '%_PARENT';
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our $errstr = "";
 
@@ -114,6 +114,7 @@ sub new {
 		Tokenizer => undef, # Where we store the tokenizer for a run
 		buffer    => [],    # The input token buffer
 		delayed   => [],    # The "delayed insignificant tokens" buffer
+		features  => [],    # Stack of features in scope
 	}, $class;
 }
 
@@ -133,6 +134,8 @@ creates a L<PPI::Tokenizer> for the content and lexes the token stream
 produced by the tokenizer. Basically, a sort of all-in-one method for
 getting a L<PPI::Document> object from a file name.
 
+Additional arguments are passed to the tokenizer as a hash.
+
 Returns a L<PPI::Document> object, or C<undef> on error.
 
 =cut
@@ -143,6 +146,7 @@ sub lex_file {
 	unless ( defined $file ) {
 		return $self->_error("Did not pass a filename to PPI::Lexer::lex_file");
 	}
+	my %args = @_;
 
 	# Create the Tokenizer
 	my $Tokenizer = eval {
@@ -154,7 +158,7 @@ sub lex_file {
 		return $self->_error( $errstr );
 	}
 
-	$self->lex_tokenizer( $Tokenizer );
+	$self->lex_tokenizer( $Tokenizer, %args );
 }
 
 =pod
@@ -165,6 +169,8 @@ The C<lex_source> method takes a normal scalar string as argument. It
 creates a L<PPI::Tokenizer> object for the string, and then lexes the
 resulting token stream.
 
+Additional arguments are passed to the tokenizer as a hash.
+
 Returns a L<PPI::Document> object, or C<undef> on error.
 
 =cut
@@ -175,6 +181,7 @@ sub lex_source {
 	unless ( defined $source and not ref $source ) {
 		return $self->_error("Did not pass a string to PPI::Lexer::lex_source");
 	}
+	my %args = @_;
 
 	# Create the Tokenizer and hand off to the next method
 	my $Tokenizer = eval {
@@ -186,7 +193,7 @@ sub lex_source {
 		return $self->_error( $errstr );
 	}
 
-	$self->lex_tokenizer( $Tokenizer );
+	$self->lex_tokenizer( $Tokenizer, %args );
 }
 
 =pod
@@ -196,6 +203,8 @@ sub lex_source {
 The C<lex_tokenizer> takes as argument a L<PPI::Tokenizer> object. It
 lexes the token stream from the tokenizer into a L<PPI::Document> object.
 
+Additional arguments are set on the L<PPI::Document> produced.
+
 Returns a L<PPI::Document> object, or C<undef> on error.
 
 =cut
@@ -206,14 +215,22 @@ sub lex_tokenizer {
 	return $self->_error(
 		"Did not pass a PPI::Tokenizer object to PPI::Lexer::lex_tokenizer"
 	) unless $Tokenizer;
+	my %args = @_;
 
 	# Create the empty document
 	my $Document = PPI::Document->new;
+	ref($Document)->_setattr( $Document, %args );
+	$Tokenizer->_document($Document);
+	if (my $feat = $Document->feature_mods) {
+		push @{$self->{features}}, $feat;
+		$Tokenizer->_features($feat);
+	}
 
 	# Lex the token stream into the document
 	$self->{Tokenizer} = $Tokenizer;
 	if ( !eval { $self->_lex_document($Document); 1 } ) {
 		# If an error occurs DESTROY the partially built document.
+		$Tokenizer->_document(undef);
 		undef $Document;
 		if ( _INSTANCE($@, 'PPI::Exception') ) {
 			return $self->_error( $@->message );
@@ -247,7 +264,7 @@ sub _lex_document {
 		}
 
 		if ( $Token->content eq ';' ) {
-			# It's a semi-colon on it's own.
+			# It's a semi-colon on its own.
 			# We call this a null statement.
 			$self->_add_element(
 				$Document,
@@ -425,8 +442,15 @@ sub _statement {
 		}
 	}
 
+	my $is_lexsub = 0;
+
 	# Is it a token in our known classes list
-	my $class = $STATEMENT_CLASSES{$Token->content};
+	my $content = $Token->content;
+	my $class =
+	    $content eq 'try' && ($self->{features}[-1] || {})->{try}
+	        ? 'PPI::Statement::Compound'
+	        : $STATEMENT_CLASSES{$content};
+
 	if ( $class ) {
 		# Is the next significant token a =>
 		# Read ahead to the next significant token
@@ -437,6 +461,29 @@ sub _statement {
 				next;
 			}
 
+			# Scheduled block must be followed by left curly or
+			# semicolon.  Otherwise we have something else (e.g.
+			# open( CHECK, ... );
+			if (
+				'PPI::Statement::Scheduled' eq $class
+				and not ( $Next->isa( 'PPI::Token::Structure' )
+					and $Next->content =~ m/\A[{;]\z/ ) # }
+			) {
+				$class = undef;
+				last;
+			}
+
+			# Lexical subroutine
+			if (
+				$content =~ /^(?:my|our|state)\z/
+				and $Next->isa( 'PPI::Token::Word' ) and $Next->content eq 'sub'
+			) {
+				# This should be PPI::Statement::Sub rather than PPI::Statement::Variable
+				$class = undef;
+				$is_lexsub = 1;
+				last;
+			}
+
 			last if
 				!$Next->isa( 'PPI::Token::Operator' ) or $Next->content ne '=>';
 
@@ -489,7 +536,7 @@ sub _statement {
 	return $class if $class;
 
 	# Handle the more in-depth sub detection
-	if ( $Token->content eq 'sub' ) {
+	if ( $is_lexsub || $content eq 'sub' ) {
 		# Read ahead to the next significant token
 		my $Next;
 		while ( $Next = $self->_get_token ) {
@@ -531,7 +578,7 @@ sub _statement {
 		return 'PPI::Statement::Sub';
 	}
 
-	if ( $Token->content eq 'use' ) {
+	if ( $content eq 'use' ) {
 		# Add a special case for "use v6" lines.
 		my $Next;
 		while ( $Next = $self->_get_token ) {
@@ -594,6 +641,18 @@ sub _statement {
 	return 'PPI::Statement';
 }
 
+sub _update_features {
+	my ($self, $statement) = @_;
+
+	if (ref $statement eq 'PPI::Statement::Include' && (my $feat = $statement->feature_mods)) {
+		push @{$self->{features}}, {} unless @{$self->{features}};
+		my $current_features = $self->{features}[-1];
+		$self->{Tokenizer}->_features(
+			$self->{features}[-1] = { %$current_features, %$feat }
+		);
+	}
+}
+
 sub _lex_statement {
 	my ($self, $Statement) = @_;
 	# my $self      = shift;
@@ -622,6 +681,7 @@ sub _lex_statement {
 			$Token->isa('PPI::Token::Separator')
 		) {
 			# Rollback and end the statement
+			$self->_update_features( $Statement );
 			return $self->_rollback( $Token );
 		}
 
@@ -630,6 +690,7 @@ sub _lex_statement {
 			# Have we hit an implicit end to the statement
 			unless ( $self->_continues( $Statement, $Token ) ) {
 				# Rollback and finish the statement
+				$self->_update_features( $Statement );
 				return $self->_rollback( $Token );
 			}
 		}
@@ -643,6 +704,7 @@ sub _lex_statement {
 		# Handle normal statement terminators
 		if ( $Token->content eq ';' ) {
 			$self->_add_element( $Statement, $Token );
+			$self->_update_features( $Statement );
 			return 1;
 		}
 
@@ -665,6 +727,7 @@ sub _lex_statement {
 
 	# No, it's just the end of the file...
 	# Roll back any insignificant tokens, they'll get added at the Document level
+	$self->_update_features( $Statement );
 	$self->_rollback;
 }
 
@@ -868,6 +931,22 @@ sub _continues {
 		return $Token->isa('PPI::Token::Structure') && $Token->content eq '{';
 	}
 
+	if ( $type eq 'try' and $LastChild->presumed_features->{try} ) {
+		return 1 if not $LastChild->isa('PPI::Structure::Block');
+
+		my $NextLast = $Statement->schild(-2);
+		return ''
+		  if $NextLast
+		  and $NextLast->isa('PPI::Token')
+		  and $NextLast->isa('PPI::Token::Word')
+		  and $NextLast->content eq 'catch';
+
+		return 1    #
+		  if $Token->isa('PPI::Token::Word') and $Token->content eq 'catch';
+
+		return '';
+	}
+
 	# Handle the common continuable block case
 	if ( $LastChild->isa('PPI::Structure::Block') ) {
 		# LABEL while (EXPR) BLOCK
@@ -1007,6 +1086,8 @@ sub _round {
 		return 'PPI::Structure::Given';
 	} elsif ( $Parent->isa('PPI::Statement::When') ) {
 		return 'PPI::Structure::When';
+	} elsif ( $Parent->isa('PPI::Statement::Sub') ) {
+		return 'PPI::Structure::Signature';
 	}
 
 	# Otherwise, it must be a list
@@ -1184,17 +1265,21 @@ sub _curly {
 	### FIXME This is possibly a bad choice, but will have to do for now.
 	return 'PPI::Structure::Block' if $Element;
 
-	# Special case: Are we the param of a core function
-	# i.e. map({ $_ => 1 } @foo)
 	if (
 		$Parent->isa('PPI::Statement')
 		and
 		_INSTANCE($Parent->parent, 'PPI::Structure::List')
 	) {
 		my $function = $Parent->parent->parent->schild(-2);
-		if ( $function and $function->content =~ /^(?:map|grep|sort)$/ ) {
-			return 'PPI::Structure::Block';
-		}
+
+		# Special case: Are we the param of a core function
+		# i.e. map({ $_ => 1 } @foo)
+		return 'PPI::Structure::Block'
+			if $function and $function->content =~ /^(?:map|grep|sort|eval|do)$/;
+
+		# If not part of a block print, list-embedded curlies are most likely constructors
+		return 'PPI::Structure::Constructor'
+			if not $function or $function->content !~ /^(?:print|say)$/;
 	}
 
 	# We need to scan ahead.
@@ -1238,6 +1323,8 @@ sub _lex_structure {
 	# my $self      = shift;
 	# my $Structure = _INSTANCE(shift, 'PPI::Structure') or die "Bad param 1";
 
+	push @{$self->{features}}, $self->{features}[-1] || {};
+
 	# Start the processing loop
 	my $Token;
 	while ( ref($Token = $self->_get_token) ) {
@@ -1276,6 +1363,8 @@ sub _lex_structure {
 
 		# Is this the close of a structure ( which would be an error )
 		if ( $Token->__LEXER__closes ) {
+			pop @{$self->{features}};
+
 			# Is this OUR closing structure
 			if ( $Token->content eq $Structure->start->__LEXER__opposite ) {
 				# Add any delayed tokens, and the finishing token (the ugly way)
@@ -1307,7 +1396,7 @@ sub _lex_structure {
 			return $self->_rollback( $Token );
 		}
 
-		# It's a semi-colon on it's own, just inside the block.
+		# It's a semi-colon on its own, just inside the block.
 		# This is a null statement.
 		$self->_add_element(
 			$Structure,
@@ -1320,6 +1409,8 @@ sub _lex_structure {
 		PPI::Exception->throw;
 	}
 
+	pop @{$self->{features}};
+
 	# No, it's just the end of file.
 	# Add any insignificant trailing tokens.
 	$self->_add_delayed( $Structure );
