@@ -5,12 +5,13 @@ package PPI::Singletons;
 use strict;
 use Exporter     ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA       = 'Exporter';
-our @EXPORT_OK = qw{ %_PARENT %OPERATOR %MAGIC %LAYER $CURLY_SYMBOL %QUOTELIKE %KEYWORDS };
+our @EXPORT_OK = qw{ %_PARENT %_POSITION_CACHE %OPERATOR %MAGIC %LAYER $CURLY_SYMBOL %QUOTELIKE %KEYWORDS };
 
 our %_PARENT; # Master Child -> Parent index
+our %_POSITION_CACHE; # cache for position in parent
 
 # operator index
 our %OPERATOR = map { $_ => 1 } (
@@ -22,7 +23,7 @@ our %OPERATOR = map { $_ => 1 } (
 	& | ^ && || // .. ...
 	? :
 	= **= += -= .= *= /= %= x= &= |= ^= <<= >>= &&= ||= //=
-	=> <>
+	=> <> <<>>
 	and or xor not
 	}, ',' 	# Avoids "comma in qw{}" warning
 );
