@@ -45,10 +45,14 @@ L<PPI::Statement>, L<PPI::Node> and L<PPI::Element> methods.
 =cut
 
 use strict;
+
+use version 0.77 ();
+use Safe::Isa '$_call_if_object';
+
 use PPI::Statement                 ();
 use PPI::Statement::Include::Perl6 ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Statement";
 
@@ -236,6 +240,109 @@ sub arguments {
 	return @args;
 }
 
+=head2 feature_mods
+
+	# `use feature 'signatures';`
+	my %mods = $include->feature_mods;
+	# { signatures => "perl" }
+
+	# `use 5.036;`
+	my %mods = $include->feature_mods;
+	# { signatures => "perl" }
+
+Returns a hashref of features identified as enabled by the include, or undef if
+the include does not enable features. The value for each feature indicates the
+provider of the feature.
+
+=cut
+
+sub feature_mods {
+	my ($self) = @_;
+	my $type = $self->type;
+	return if $type eq "require";
+
+	if ( my $cb_features = $self->_custom_feature_include_cb->($self) )    #
+	{ return $cb_features; }
+
+	if ( my $perl_version = $self->version ) {
+		## tried using feature.pm, but it is impossible to install future
+		## versions of it, so e.g. a 5.20 install cannot know about
+		## 5.36 features
+
+		# crude proof of concept hack due to above
+		return { signatures => "perl" }
+		  if version::->parse($perl_version) >= 5.035;
+	}
+
+        my $module = $self->module or return;
+
+	my %known     = ( signatures => 1, try => 1 );
+	my $on_or_off = $type eq "use";
+
+	if ( $on_or_off
+		and my $custom = $self->_custom_feature_includes->{ $module } )  #
+	{ return $custom; }
+
+	if ( $module eq "feature" ) {
+		my @features = grep $known{$_}, $self->_decompose_arguments;
+		return { map +( $_ => $on_or_off ? "perl" : 0 ), @features };
+	}
+	elsif ( $module eq "Mojolicious::Lite" ) {
+		my $wants_signatures = grep /-signatures/, $self->_decompose_arguments;
+		return { signatures => $wants_signatures ? "perl" : 0 };
+	}
+	elsif ( $module eq "Modern::Perl" ) {
+		my $v = $self->module_version->$_call_if_object("literal") || 0;
+		return { signatures => $v >= 2023 ? "perl" : 0 };
+	}
+	elsif ( $module eq "experimental" ) {
+		my $wants_signatures = grep /signatures/, $self->_decompose_arguments;
+		return { signatures => $wants_signatures ? "perl" : 0 };
+	}
+	elsif ( $module eq "Syntax::Keyword::Try" ) {
+		return { try => $on_or_off ? "Syntax::Keyword::Try" : 0 };
+	}
+
+	return;
+}
+
+sub _decompose_arguments {
+	my ($self) = @_;
+	my @args = $self->arguments;
+	while ( grep ref, @args ) {
+		@args = map $self->_decompose_argument($_), @args;
+	}
+	return @args;
+}
+
+sub _decompose_argument {
+	my ( $self, $arg ) = @_;
+	return $arg->children
+	  if $arg->isa("PPI::Structure::List")
+	  or $arg->isa("PPI::Statement::Expression");
+	my $as_text = $arg->can("literal") || $arg->can("string");
+	return $as_text->($arg) if $as_text;
+	return if $arg->isa("PPI::Token::Operator")
+	  or $arg->content eq ",";
+	warn "possibly unrecognized feature because of unknown arg decompose"
+	 . " type: '$arg' : " . ref $arg;
+	return;
+}
+
+sub _custom_feature_includes {
+	my ($self) = @_;
+	return unless                                                             #
+	  my $document = $self->document;
+	return $document->custom_feature_includes || {};
+}
+
+sub _custom_feature_include_cb {
+	my ($self) = @_;
+	return unless                                                             #
+	  my $document = $self->document;
+	return $document->custom_feature_include_cb || sub { };
+}
+
 1;
 
 =pod
