@@ -35,7 +35,7 @@ use List::Util     ();
 use Params::Util   qw{_INSTANCE};
 use PPI::Statement ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Statement";
 
@@ -75,7 +75,8 @@ sub name {
 	my ($self) = @_;
 
 	# Usually the second token is the name.
-	my $token = $self->schild(1);
+	# The third token is the name if this is a lexical subroutine.
+	my $token = $self->schild(defined $self->type ? 2 : 1);
 	return $token->content
 	  if defined $token and $token->isa('PPI::Token::Word');
 
@@ -170,6 +171,32 @@ sub reserved {
 	$name eq uc $name;
 }
 
+=pod
+
+=head2 type
+
+The C<type> method checks and returns the declaration type of the statement,
+which will be one of 'my', 'our', or 'state'.
+
+Returns a string of the type, or C<undef> if the type is not declared.
+
+=cut
+
+sub type {
+	my $self = shift;
+
+	# Get the first significant child
+	my @schild = grep { $_->significant } $self->children;
+
+	# Ignore labels
+	shift @schild if _INSTANCE($schild[0], 'PPI::Token::Label');
+
+	# Get the type
+	(_INSTANCE($schild[0], 'PPI::Token::Word') and $schild[0]->content =~ /^(my|our|state)$/)
+		? $schild[0]->content
+		: undef;
+}
+
 1;
 
 =pod
