@@ -28,10 +28,17 @@ our parent L<PPI::Token> and L<PPI::Element> classes.
 =cut
 
 use strict;
-use IO::String ();
 use PPI::Token ();
 
-our $VERSION = '1.237_001';
+# IO::String emulates file handles using in memory strings. Perl can do this
+# directly on perl 5.8+
+use constant USE_IO_STRING => $] < '5.008000';
+use if USE_IO_STRING, 'IO::String';
+# code may expect methods to be available on all file handles, so make sure
+# IO is loaded
+use if !USE_IO_STRING, 'IO::File';
+
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token";
 
@@ -60,7 +67,14 @@ Returns an L<IO::String> object.
 
 sub handle {
 	my $self = shift;
-	IO::String->new( \$self->{content} );
+	# perl 5.6 compatibility
+	if (USE_IO_STRING) {
+		return IO::String->new( \$self->{content} );
+	}
+	else {
+		open my $fh, '+<', \$self->{content};
+		return $fh;
+	}
 }
 
 sub __TOKENIZER__on_line_start {
