@@ -72,7 +72,7 @@ but for the most part they should more or less DWYM.
 Although technically it can be considered a quote, for the time being
 C<HereDocs> are being treated as a completely separate C<Token> subclass,
 and will not be found in a search for L<PPI::Token::Quote> or
-L<PPI::Token::QuoteLike objects>.
+L<PPI::Token::QuoteLike> objects.
 
 This may change in the future, with it most likely to end up under
 QuoteLike.
@@ -85,9 +85,8 @@ have a relatively large number of unique methods all of their own.
 =cut
 
 use strict;
-use PPI::Token ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token";
 
@@ -111,11 +110,20 @@ the here-doc, B<excluding> the terminator line.
 
 =cut
 
-sub heredoc {
-	wantarray
-		? @{shift->{_heredoc}}
-		: scalar @{shift->{_heredoc}};
-}
+sub heredoc { @{shift->{_heredoc}} }
+
+=pod
+
+=head2 indentation
+
+The C<indentation> method returns the indentation string of an indented
+here-doc if that can be determined. If the indented here-doc is damaged
+(say, missing terminator) or the here-doc was not indented, it returns
+C<undef>.
+
+=cut
+
+sub indentation { shift->{_indentation} }
 
 =pod
 
@@ -133,6 +141,25 @@ sub terminator {
 	shift->{_terminator};
 }
 
+sub _is_terminator {
+	my ( $self, $terminator, $line, $indented ) = @_;
+	if ( $indented ) {
+		return $line =~ /^\s*\Q$terminator\E$/;
+	} else {
+		return $line eq $terminator;
+	}
+}
+
+sub _indent {
+	my ( $self, $token ) = @_;
+	my ($indent) = $token->{_terminator_line} =~ /^(\s*)/;
+	return $indent;
+}
+
+sub _is_match_indent {
+	my ( $self, $token, $indent ) = @_;
+	return (grep { /^$indent/ || $_ eq "\n" } @{$token->{_heredoc}}) == @{$token->{_heredoc}};
+}
 
 
 
@@ -142,7 +169,7 @@ sub terminator {
 
 # Parse in the entire here-doc in one call
 sub __TOKENIZER__on_char {
-	my $t     = $_[1];
+	my ( $self, $t ) = @_;
 
 	# We are currently located on the first char after the <<
 
@@ -151,7 +178,8 @@ sub __TOKENIZER__on_char {
 	### for the null here-doc, which terminates at the first
 	### empty line.
 	pos $t->{line} = $t->{line_cursor};
-	if ( $t->{line} !~ m/\G( \s* (?: "[^"]*" | '[^']*' | `[^`]*` | \\?\w+ ) )/gcx ) {
+
+	if ( $t->{line} !~ m/\G( ~? \s* (?: "[^"]*" | '[^']*' | `[^`]*` | \\?\w+ ) )/gcx ) {
 		# Degenerate to a left-shift operation
 		$t->{token}->set_class('Operator');
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
@@ -166,33 +194,38 @@ sub __TOKENIZER__on_char {
 	# Find the terminator, clean it up and determine
 	# the type of here-doc we are dealing with.
 	my $content = $token->{content};
-	if ( $content =~ /^\<\<(\w+)$/ ) {
+	if ( $content =~ /^\<\<(~?)(\w+)$/ ) {
 		# Bareword
 		$token->{_mode}       = 'interpolate';
-		$token->{_terminator} = $1;
+		$token->{_indented}   = 1 if $1 eq '~';
+		$token->{_terminator} = $2;
 
-	} elsif ( $content =~ /^\<\<\s*\'(.*)\'$/ ) {
+	} elsif ( $content =~ /^\<\<(~?)\s*\'(.*)\'$/ ) {
 		# ''-quoted literal
 		$token->{_mode}       = 'literal';
-		$token->{_terminator} = $1;
+		$token->{_indented}   = 1 if $1 eq '~';
+		$token->{_terminator} = $2;
 		$token->{_terminator} =~ s/\\'/'/g;
 
-	} elsif ( $content =~ /^\<\<\s*\"(.*)\"$/ ) {
+	} elsif ( $content =~ /^\<\<(~?)\s*\"(.*)\"$/ ) {
 		# ""-quoted literal
 		$token->{_mode}       = 'interpolate';
-		$token->{_terminator} = $1;
+		$token->{_indented}   = 1 if $1 eq '~';
+		$token->{_terminator} = $2;
 		$token->{_terminator} =~ s/\\"/"/g;
 
-	} elsif ( $content =~ /^\<\<\s*\`(.*)\`$/ ) {
+	} elsif ( $content =~ /^\<\<(~?)\s*\`(.*)\`$/ ) {
 		# ``-quoted command
 		$token->{_mode}       = 'command';
-		$token->{_terminator} = $1;
+		$token->{_indented}   = 1 if $1 eq '~';
+		$token->{_terminator} = $2;
 		$token->{_terminator} =~ s/\\`/`/g;
 
-	} elsif ( $content =~ /^\<\<\\(\w+)$/ ) {
+	} elsif ( $content =~ /^\<\<(~?)\\(\w+)$/ ) {
 		# Legacy forward-slashed bareword
 		$token->{_mode}       = 'literal';
-		$token->{_terminator} = $1;
+		$token->{_indented}   = 1 if $1 eq '~';
+		$token->{_terminator} = $2;
 
 	} else {
 		# WTF?
@@ -203,11 +236,23 @@ sub __TOKENIZER__on_char {
 	$token->{_heredoc} = \my @heredoc;
 	my $terminator = $token->{_terminator} . "\n";
 	while ( defined( my $line = $t->_get_line ) ) {
-		if ( $line eq $terminator ) {
+		if ( $self->_is_terminator( $terminator, $line, $token->{_indented} ) ) {
 			# Keep the actual termination line for consistency
 			# when we are re-assembling the file
 			$token->{_terminator_line} = $line;
 
+			if ( $token->{_indented} ) {
+				my $indent = $self->_indent( $token );
+				$token->{_indentation} = $indent;
+				# Indentation of here-doc doesn't match delimiter
+				unless ( $self->_is_match_indent( $token, $indent ) ) {
+					push @heredoc, $line;
+					last;
+				}
+
+				s/^$indent// for @heredoc, $token->{_terminator_line};
+			}
+
 			# The HereDoc is now fully parsed
 			return $t->_finalize_token->__TOKENIZER__on_char( $t );
 		}
@@ -236,7 +281,18 @@ sub __TOKENIZER__on_char {
 		# newline at the end. If so, remove it from the content and set it as
 		# the terminator line.
 		$token->{_terminator_line} = pop @heredoc
-		  if $heredoc[-1] eq $token->{_terminator};
+			if $self->_is_terminator( $token->{_terminator}, $heredoc[-1], $token->{_indented} );
+	}
+
+	if ( $token->{_indented} && $token->{_terminator_line} ) {
+		my $indent = $self->_indent( $token );
+		$token->{_indentation} = $indent;
+		if ( $self->_is_match_indent( $token, $indent ) ) {
+			# Remove indent from here-doc as much as possible
+			s/^$indent// for @heredoc;
+		}
+
+		s/^$indent// for $token->{_terminator_line};
 	}
 
 	# Set a hint for PPI::Document->serialize so it can
