@@ -31,7 +31,7 @@ represent floating point numbers with exponential notation.
 use strict;
 use PPI::Token::Number::Float ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token::Number::Float";
 
@@ -51,6 +51,10 @@ sub literal {
 	$mantissa =~ s/^\./0./;
 	$exponent =~ s/^\+//;
 
+	# Must cast exponent as numeric type, due to string type '00' exponent
+	# creating false positive condition in for() loop below, causing infinite loop
+	$exponent += 0;
+
 	# This algorithm is reasonably close to the S_mulexp10()
 	# algorithm from the Perl source code, so it should arrive
 	# at the same answer as Perl most of the time.
