@@ -23,7 +23,7 @@ PPI::Token::Operator - Token class for operators
   ?    :    **=  +=   -=   .=   *=   /=
   %=   x=   &=   |=   ^=   <<=  >>=  &&=
   ||=  //=  <    >    <=   >=   <>   =>   ->
-  and  or   xor  not  eq   ne
+  and  or   xor  not  eq   ne   <<>>
 
 
 =head1 DESCRIPTION
@@ -43,7 +43,7 @@ use strict;
 use PPI::Token ();
 use PPI::Singletons '%OPERATOR';
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token";
 
@@ -60,6 +60,11 @@ sub __TOKENIZER__on_char {
 
 	# Are we still an operator if we add the next character
 	my $content = $t->{token}->{content};
+	# special case for <<>> operator
+	if(length($content) < 4 &&
+		$content . substr( $t->{line}, $t->{line_cursor}, 4 - length($content) ) eq '<<>>') {
+		return 1;
+	}
 	return 1 if $OPERATOR{ $content . $char };
 
 	# Handle the special case of a .1234 decimal number
@@ -74,10 +79,11 @@ sub __TOKENIZER__on_char {
 	# Handle the special case if we might be a here-doc
 	if ( $content eq '<<' ) {
 		pos $t->{line} = $t->{line_cursor};
-		# Either <<FOO or << 'FOO' or <<\FOO
+		# Either <<FOO  or << 'FOO'  or <<\FOO  or
+		#        <<~FOO or <<~ 'FOO' or <<~\FOO
 		### Is the zero-width look-ahead assertion really
 		### supposed to be there?
-		if ( $t->{line} =~ m/\G(?: (?!\d)\w | \s*['"`] | \\\w ) /gcx ) {
+		if ( $t->{line} =~ m/\G ~? (?: (?!\d)\w | \s*['"`] | \\\w ) /gcx ) {
 			# This is a here-doc.
 			# Change the class and move to the HereDoc's own __TOKENIZER__on_char method.
 			$t->{class} = $t->{token}->set_class('HereDoc');
@@ -86,9 +92,8 @@ sub __TOKENIZER__on_char {
 	}
 
 	# Handle the special case of the null Readline
-	if ( $content eq '<>' ) {
-		$t->{class} = $t->{token}->set_class('QuoteLike::Readline');
-	}
+	$t->{class} = $t->{token}->set_class('QuoteLike::Readline')
+		if $content eq '<>' or $content eq '<<>>';
 
 	# Finalize normally
 	$t->_finalize_token->__TOKENIZER__on_char( $t );
