@@ -30,7 +30,7 @@ use strict;
 use PPI::Token::Quote              ();
 use PPI::Token::_QuoteEngine::Full ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = qw{
 	PPI::Token::_QuoteEngine::Full
@@ -47,8 +47,9 @@ our @ISA = qw{
 sub string {
 	my $self     = shift;
 	my @sections = $self->_sections;
-	my $str      = $sections[0];
-	substr( $self->{content}, $str->{position}, $str->{size} );	
+	return unless    #
+	  my $str = $sections[0];
+	substr( $self->{content}, $str->{position}, $str->{size} );
 }
 
 
