@@ -31,7 +31,7 @@ use strict;
 use Params::Util qw{_INSTANCE};
 use PPI::Token   ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token";
 
@@ -80,7 +80,7 @@ Returns the symbol as a string.
 
 =cut
 
-my %cast_which_trumps_braces = map { $_ => 1 } qw{ $ @ };
+my %cast_which_trumps_braces = map { $_ => 1 } qw{ $ @ % };
 
 sub symbol {
 	my $self   = shift;
@@ -88,7 +88,6 @@ sub symbol {
 
 	# Immediately return the cases where it can't be anything else
 	my $type = substr( $symbol, 0, 1 );
-	return $symbol if $type eq '%';
 	return $symbol if $type eq '&';
 
 	# Unless the next significant Element is a structure, it's correct.
@@ -113,6 +112,9 @@ sub symbol {
 	} elsif ( $type eq '@' ) {
 		substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
 
+	} elsif ( $type eq '%' ) {
+		substr( $symbol, 0, 1, '@' ) if $braces eq '[]';
+
 	}
 
 	$symbol;
@@ -194,18 +196,24 @@ sub __TOKENIZER__on_char {
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 
-	# Trim off anything we oversucked...
-	$content =~ /^(
+	# Verify and extract actual full symbol name from sigil to end
+	my $sep = qr/ (?: :: | '(?!\d) ) /x; # :: and ' are namespace separators
+	my $pattern = qr/
+	^(
 		[\$@%&*]
-		(?: : (?!:) | # Allow single-colon non-magic variables
-			(?: \w+ | \' (?!\d) \w+ | \:: \w+ )
-			(?:
-				# Allow both :: and ' in namespace separators
-				(?: \' (?!\d) \w+ | \:: \w+ )
-			)*
-			(?: :: )? # Technically a compiler-magic hash, but keep it here
+		(?:
+				: (?! : )			# allow single-colon non-magic variables
+			|
+				$sep?				# optional separator
+				\w+					# a word
+				(?: $sep \w+ )* 	# optionally more separator+word pairs
+				(?: ::		 )?		# optionally what's technically a
+									# compiler-magic hash, but keep it here
 		)
-	)/x or return undef;
+	)
+	/x;
+	return undef if $content !~ $pattern;
+
 	unless ( length $1 eq length $content ) {
 		$t->{line_cursor} += length($1) - length($content);
 		$t->{token}->{content} = $1;
