@@ -32,7 +32,7 @@ use PPI::Token     ();
 use PPI::Exception ();
 use PPI::Singletons qw' %MAGIC $CURLY_SYMBOL ';
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token";
 
@@ -115,6 +115,15 @@ sub __TOKENIZER__on_char {
 			return 1;
 		}
 
+		# Is it a nameless arg in a signature?
+		if ( $char eq ')' or $char eq '=' or $char eq ',' ) {
+			my $has_sig = $t->_current_token_has_signatures_active;
+			if ($has_sig) {
+				$t->{class} = $t->{token}->set_class('Symbol');
+				return $t->_finalize_token->__TOKENIZER__on_char($t);
+			}
+		}
+
 		if ( $MAGIC{ $c . $char } ) {
 			# Magic variable
 			$t->{class} = $t->{token}->set_class( 'Magic' );
@@ -153,6 +162,15 @@ sub __TOKENIZER__on_char {
 			return 1;
 		}
 
+		# Is it a nameless arg in a signature?
+		if ( $char eq ')' ) {
+			my $has_sig = $t->_current_token_has_signatures_active;
+			if ($has_sig) {
+				$t->{class} = $t->{token}->set_class('Symbol');
+				return $t->_finalize_token->__TOKENIZER__on_char($t);
+			}
+		}
+
 		if ( $MAGIC{ $c . $char } ) {
 			# Magic variable
 			$t->{class} = $t->{token}->set_class( 'Magic' );
@@ -198,6 +216,15 @@ sub __TOKENIZER__on_char {
 			return $t->_finalize_token->__TOKENIZER__on_char( $t );
 		}
 
+		# Is it a nameless arg in a signature?
+		if ( $char eq ')' ) {
+			my $has_sig = $t->_current_token_has_signatures_active;
+			if ($has_sig) {
+				$t->{class} = $t->{token}->set_class('Symbol');
+				return $t->_finalize_token->__TOKENIZER__on_char($t);
+			}
+		}
+
 		# Is it a magic variable?
 		if ( $char eq '^' || $MAGIC{ $c . $char } ) {
 			$t->{class} = $t->{token}->set_class( 'Magic' );
