@@ -45,7 +45,7 @@ use strict;
 use Clone      ();
 use PPI::Token ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 our @ISA = "PPI::Token";
 
@@ -212,7 +212,9 @@ sub __TOKENIZER__on_char {
 		# 2. The one before that is the word 'sub'.
 		# 3. The one before that is a 'structure'
 
-		# Get the three previous significant tokens
+		my $has_sig = $t->_current_token_has_signatures_active;
+		return 'Structure' if $has_sig;
+
 		my @tokens = $t->_previous_significant_tokens(3);
 
 		# A normal subroutine declaration
@@ -237,6 +239,12 @@ sub __TOKENIZER__on_char {
 					and
 					$p2->content eq ''
 				)
+				or (
+					# Lexical subroutine
+					$p2->isa('PPI::Token::Word')
+					and
+					$p2->content =~ /^(?:my|our|state)$/
+				)
 			)
 		) {
 			# This is a sub prototype
@@ -273,10 +281,8 @@ sub __TOKENIZER__on_char {
 		return 'Operator' if $prev and $prev->isa('PPI::Token::ArrayIndex');
 
 		# If it is <<... it's a here-doc instead
-		my $next_char = substr( $t->{line}, $t->{line_cursor} + 1, 1 );
-		if ( $next_char eq '<' ) {
-			return 'Operator';
-		}
+		my $next_char = substr( $t->{line}, $t->{line_cursor} + 1, 2 );
+		return 'Operator' if $next_char =~ /<[^>]/;
 
 		return 'Operator' if not $prev;
 
@@ -284,18 +290,12 @@ sub __TOKENIZER__on_char {
 		# while ( <...> )
 		# while <>;
 		my $prec = $prev->content;
-		if ( $prev->isa('PPI::Token::Structure') and $prec eq '(' ) {
-			return 'QuoteLike::Readline';
-		}
-		if ( $prev->isa('PPI::Token::Word') and $prec eq 'while' ) {
-			return 'QuoteLike::Readline';
-		}
-		if ( $prev->isa('PPI::Token::Operator') and $prec eq '=' ) {
-			return 'QuoteLike::Readline';
-		}
-		if ( $prev->isa('PPI::Token::Operator') and $prec eq ',' ) {
-			return 'QuoteLike::Readline';
-		}
+		return 'QuoteLike::Readline'
+			if ( $prev->isa('PPI::Token::Structure') and $prec eq '(' )
+			or ( $prev->isa('PPI::Token::Structure') and $prec eq ';' )
+			or ( $prev->isa('PPI::Token::Word')      and $prec eq 'while' )
+			or ( $prev->isa('PPI::Token::Operator')  and $prec eq '=' )
+			or ( $prev->isa('PPI::Token::Operator')  and $prec eq ',' );
 
 		if ( $prev->isa('PPI::Token::Structure') and $prec eq '}' ) {
 			# Could go either way... do a regex check
