@@ -86,8 +86,9 @@ use PPI::Element    ();
 use PPI::Token      ();
 use PPI::Exception  ();
 use PPI::Exception::ParserRejection ();
+use PPI::Document ();
 
-our $VERSION = '1.237_001';
+our $VERSION = '1.28401'; # TRIAL
 
 # The x operator cannot follow most Perl operators, implying that
 # anything beginning with x following an operator is a word.
@@ -159,6 +160,7 @@ sub new {
 		# Source code
 		source       => undef,
 		source_bytes => undef,
+		document     => undef,
 
 		# Line buffer
 		line         => undef,
@@ -170,6 +172,7 @@ sub new {
 		token        => undef,
 		class        => 'PPI::Token::BOM',
 		zone         => 'PPI::Token::Whitespace',
+		features     => undef,
 
 		# Output token buffer
 		tokens       => [],
@@ -248,6 +251,11 @@ sub new {
 	$self;
 }
 
+sub _document {
+	my $self = shift;
+	return @_ ? $self->{document} = shift : $self->{document};
+}
+
 
 
 
@@ -573,8 +581,8 @@ sub _process_next_char {
 		return undef;
 	}
 
-	# Increment the counter and check for end of line
-	return 0 if ++$self->{line_cursor} >= $self->{line_length};
+    $self->{line_cursor}++;
+    return 0 if $self->_at_line_end;
 
 	# Pass control to the token class
 	my $result;
@@ -614,6 +622,11 @@ sub _process_next_char {
 	1;
 }
 
+sub _at_line_end {
+    my ($self) = @_;
+    return $self->{line_cursor} >= $self->{line_length};
+}
+
 
 
 
@@ -847,6 +860,16 @@ sub __current_token_is_forced_word {
 	return '';
 }
 
+sub _features {
+	my $self = shift;
+	return @_ ? $self->{features} = shift : $self->{features} || {};
+}
+
+sub _current_token_has_signatures_active {
+	my $self = shift;
+	return $self->{features}{signatures};
+}
+
 1;
 
 =pod
