@@ -8,9 +8,7 @@ use Test::More;
 use Test::Object;
 use lib 't/lib';
 use PPI::Test::Object;
-
-our $VERSION = '1.237_001';
-
+use Helper 'safe_new';
 
 #####################################################################
 # Process a .code/.dump file pair
@@ -24,10 +22,10 @@ sub run_testdir {
 	ok( (-e $testdir and -d $testdir and -r $testdir), "Test directory $testdir found" );
 
 	# Find the .code test files
-	local *TESTDIR;
-	opendir( TESTDIR, $testdir ) or die "opendir: $!";
-	my @code = map { catfile( $testdir, $_ ) } sort grep { /\.code$/ } readdir(TESTDIR);
-	closedir( TESTDIR ) or die "closedir: $!";
+	my @code = do {
+		opendir my $TESTDIR, $testdir or die "opendir: $!";
+		map { catfile $testdir, $_ } sort grep /\.code$/, readdir $TESTDIR;
+	};
 	ok( scalar @code, 'Found at least one code file' );
 
 	foreach my $codefile ( @code ) {
@@ -36,15 +34,13 @@ sub run_testdir {
 		$dumpfile =~ s/\.code$/\.dump/;
 		my $codename = $codefile;
 		$codename =~ s/\.code$//;
-		ok( (-f $dumpfile and -r $dumpfile), "$codename: Found matching .dump file" );
+		my $has_dumpfile = -f $dumpfile and -r $dumpfile;
+		ok( $has_dumpfile, "$codename: Found matching .dump file" );
 
 		# Create the lexer and get the Document object
-		my $document = PPI::Document->new( $codefile );
+		my $document = safe_new $codefile;
 		ok( $document, "$codename: Lexer->Document returns true" );
-		ok( _INSTANCE($document, 'PPI::Document'), "$codename: Object isa PPI::Document" );
 
-		my $rv;
-		local *CODEFILE;
 		SKIP: {
 			skip "No Document to test", 12 unless $document;
 
@@ -61,28 +57,25 @@ sub run_testdir {
 			ok( scalar @dump_list, "$codename: Got dump content from dumper" );
 
 			# Try to get the .dump file array
-			local *DUMP;
-			open( DUMP, '<', $dumpfile ) or die "open: $!";
-			my @content = <DUMP>;
-			close( DUMP ) or die "close: $!";
+			my @content = !$has_dumpfile ? () : do {
+				open my $DUMP, '<', $dumpfile or die "open: $!";
+				binmode $DUMP;
+				<$DUMP>;
+			};
 			chomp @content;
 
 			# Compare the two
 			{
 			local $TODO = $ENV{TODO} if $ENV{TODO};
-			is_deeply( \@dump_list, \@content, "$codename: Generated dump matches stored dump" );
+			is_deeply( \@dump_list, \@content, "$codename: Generated dump matches stored dump" )
+			  or diag map "$_\n", @dump_list;
 			}
-
-			# Also, do a round-trip check
-			$rv = open( CODEFILE, '<', $codefile );
-			ok( $rv, "$codename: Opened file" );
 		}
 		SKIP: {
-			unless ( $document and $rv ) {
-				skip "Missing file", 1;
-			}
-			my $source = do { local $/ = undef; <CODEFILE> };
-			close CODEFILE;
+			# Also, do a round-trip check
+			skip "No roundtrip check: Couldn't parse code file before", 1 if !$document;
+			skip "No roundtrip check: Couldn't open code file '$codename', $!", 1 unless #
+			  my $source = do { open my $CODEFILE, '<', $codefile; binmode $CODEFILE; local $/; <$CODEFILE> };
 			$source =~ s/(?:\015{1,2}\012|\015|\012)/\n/g;
 
 			is( $document->serialize, $source, "$codename: Round-trip back to source was ok" );
@@ -107,43 +100,32 @@ sub increment_testdir {
 	ok( (-e $testdir and -d $testdir and -r $testdir), "Test directory $testdir found" );
 
 	# Find the .code test files
-	local *TESTDIR;
-	opendir( TESTDIR, $testdir ) or die "opendir: $!";
-	my @code = map { catfile( $testdir, $_ ) } sort grep { /\.code$/ } readdir(TESTDIR);
-	closedir( TESTDIR ) or die "closedir: $!";
+	my @code = do {
+		opendir my $TESTDIR, $testdir or die "opendir: $!";
+		map { catfile $testdir, $_ } sort grep /\.code$/, readdir $TESTDIR;
+	};
 	ok( scalar @code, 'Found at least one code file' );
 
-	foreach my $codefile ( @code ) {
+	for my $codefile ( @code ) {
 		# Does the .code file have a matching .dump file
 		my $codename = $codefile;
 		$codename =~ s/\.code$//;
 
 		# Load the file
-		local *CODEFILE;
-		local $/ = undef;
-		open( CODEFILE, '<', $codefile ) or die "open: $!";
-		my $buffer = <CODEFILE>;
-		close( CODEFILE ) or die "close: $!";
+		my $buffer = do {
+			local $/;
+			open my $CODEFILE, '<', $codefile or die "open: $!";
+			binmode $CODEFILE;
+			<$CODEFILE>;
+		};
 
 		# Cover every possible transitional state in
 		# the regression test code fragments.
-		foreach my $chars ( 1 .. length($buffer) ) {
-			my $string   = substr( $buffer, 0, $chars );
-			my $document = eval {
-				PPI::Document->new( \$string );
-			};
-			is(
-				$@ => '',
-				"$codename: $chars chars ok",
-			);
-			is(
-				ref($document) => 'PPI::Document',
-				"$codename: $chars chars document",
-			);
-			is(
-				$document->serialize => $string,
-				"$codename: $chars char roundtrip",
-			);
+		for my $chars ( 1 .. length $buffer ) {
+			my $string   = substr $buffer, 0, $chars;
+			my $document = eval { safe_new \$string };
+			is( $@ => '', "$codename: $chars chars ok" );
+			is( $document->serialize => $string, "$codename: $chars char roundtrip" );
 		}
 	}
 }
